==> haskell-ghcide-test-utils-1.9.0.0-232-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-FOz3tMLAof0D2rLuigsBWR
key:                  ghcide-test-utils-1.9.0.0-FOz3tMLAof0D2rLuigsBWR
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  cf4a77ea057c3c9e3086ae99964eff46
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-FOz3tMLAof0D2rLuigsBWR
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR directory-1.3.7.1
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8 filepath-1.4.2.2
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-test-0.15.0.1-BGEj1b5aDdg5k2rLtas9eE
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA
    tasty-hunit-0.10.2-EW3UORbab3JJyhoumRdA8U text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-test-utils-1.9.0.0-267-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-JBlCeenuDt56Sfp0hiTaeq
key:                  ghcide-test-utils-1.9.0.0-JBlCeenuDt56Sfp0hiTaeq
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  c772c2e93edf4497163d623a53bf7557
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-JBlCeenuDt56Sfp0hiTaeq
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi directory-1.3.7.1
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E filepath-1.4.2.2
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-test-0.15.0.1-6xbEqv855SH8gUFKA5jj3l
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400
    tasty-hunit-0.10.2-KQQ8gauHRJMLeGTwOTr3bh text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
